@@ -1,12 +1,12 @@
 __copyright__ = "Copyright (c) 2020 Jina AI Limited. All rights reserved."
 __license__ = "Apache-2.0"
 
-from typing import Iterable, Tuple
+from typing import Tuple
 
 from .. import QuerySetReader, BaseRecursiveDriver
 
 if False:
-    from ...proto import jina_pb2
+    from ...types.sets import DocumentSet
 
 
 class ExcludeQL(QuerySetReader, BaseRecursiveDriver):
@@ -32,7 +32,7 @@ class ExcludeQL(QuerySetReader, BaseRecursiveDriver):
         else:
             self._fields = set(fields)
 
-    def _apply_all(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs):
+    def _apply_all(self, docs: 'DocumentSet', *args, **kwargs):
         for doc in docs:
             for k in self.fields:
                 doc.ClearField(k)
@@ -51,7 +51,7 @@ class SelectQL(ExcludeQL):
         SelectQL will ensure that the `outgoing` documents only contain the field `matches`
     """
 
-    def _apply_all(self, docs: Iterable['jina_pb2.Document'], *args, **kwargs):
+    def _apply_all(self, docs: 'DocumentSet', *args, **kwargs):
         for doc in docs:
             for k in doc.DESCRIPTOR.fields_by_name.keys():
                 if k not in self.fields:
