@@ -76,6 +76,10 @@ class EmptyExecutorYAML(Exception):
     """The yaml config file is empty, nothing to read from there."""
 
 
+class BadConfigSource(FileNotFoundError):
+    """The yaml config file is bad, not loadable or not exist"""
+
+
 class BadWorkspace(Exception):
     """Can not determine the separate storage strategy for the executor"""
 
