@@ -36,12 +36,12 @@ def reduce_min(data: 'np.ndarray', mask_2d: 'np.ndarray') -> 'np.ndarray':
     return np.min(output, axis=1)
 
 
-def reduce_cls(data: 'np.ndarray', mask_2d: 'np.ndarray', cls_pos='head'):
+def reduce_cls(data: 'np.ndarray', mask_2d: 'np.ndarray', cls_pos: str = 'head') -> 'np.ndarray':
     mask_pruned = prune_mask(mask_2d, cls_pos)
     return reduce_mean(data, mask_pruned)
 
 
-def prune_mask(mask, cls_pos='head'):
+def prune_mask(mask: 'np.ndarray', cls_pos: str='head') -> 'np.ndarray':
     result = np.zeros(mask.shape)
     if cls_pos == 'head':
         mask_row = np.zeros((1, mask.shape[1]))
@@ -49,7 +49,7 @@ def prune_mask(mask, cls_pos='head'):
         result = np.tile(mask_row, (mask.shape[0], 1))
     elif cls_pos == 'tail':
         for row_index, num_tokens in enumerate(np.sum(mask, axis=1).tolist()):
-            result[row_index, num_tokens - 1] = 1
+            result[row_index, int(num_tokens) - 1] = 1
     else:
         raise NotImplementedError
     return result
