@@ -113,7 +113,7 @@ class AsyncFlow(BaseFlow):
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
-        await self._get_client(**kwargs).train(input_fn, on_done, on_error, on_always, **kwargs)
+        return await self._get_client(**kwargs).train(input_fn, on_done, on_error, on_always, **kwargs)
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     async def index_ndarray(self, array: 'np.ndarray', axis: int = 0, size: int = None, shuffle: bool = False,
@@ -133,8 +133,9 @@ class AsyncFlow(BaseFlow):
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
         from ..clients.sugary_io import _input_ndarray
-        await self._get_client(**kwargs).index(_input_ndarray(array, axis, size, shuffle),
-                                               on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
+        return await self._get_client(**kwargs).index(_input_ndarray(array, axis, size, shuffle),
+                                                      on_done, on_error, on_always, data_type=DataInputType.CONTENT,
+                                                      **kwargs)
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     async def search_ndarray(self, array: 'np.ndarray', axis: int = 0, size: int = None, shuffle: bool = False,
@@ -178,8 +179,9 @@ class AsyncFlow(BaseFlow):
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
         from ..clients.sugary_io import _input_lines
-        await self._get_client(**kwargs).index(_input_lines(lines, filepath, size, sampling_rate, read_mode),
-                                               on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
+        return await self._get_client(**kwargs).index(_input_lines(lines, filepath, size, sampling_rate, read_mode),
+                                                      on_done, on_error, on_always, data_type=DataInputType.CONTENT,
+                                                      **kwargs)
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     async def index_files(self, patterns: Union[str, List[str]], recursive: bool = True,
@@ -203,8 +205,9 @@ class AsyncFlow(BaseFlow):
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
         from ..clients.sugary_io import _input_files
-        await self._get_client(**kwargs).index(_input_files(patterns, recursive, size, sampling_rate, read_mode),
-                                               on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
+        return await self._get_client(**kwargs).index(_input_files(patterns, recursive, size, sampling_rate, read_mode),
+                                                      on_done, on_error, on_always, data_type=DataInputType.CONTENT,
+                                                      **kwargs)
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     async def search_files(self, patterns: Union[str, List[str]], recursive: bool = True,
@@ -228,8 +231,9 @@ class AsyncFlow(BaseFlow):
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
         from ..clients.sugary_io import _input_files
-        await self._get_client(**kwargs).search(_input_files(patterns, recursive, size, sampling_rate, read_mode),
-                                                on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
+        return await self._get_client(**kwargs).search(
+            _input_files(patterns, recursive, size, sampling_rate, read_mode),
+            on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     async def search_lines(self, filepath: str = None, lines: Iterator[str] = None, size: int = None,
@@ -252,8 +256,9 @@ class AsyncFlow(BaseFlow):
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
         from ..clients.sugary_io import _input_lines
-        await self._get_client(**kwargs).search(_input_lines(lines, filepath, size, sampling_rate, read_mode),
-                                                on_done, on_error, on_always, data_type=DataInputType.CONTENT, **kwargs)
+        return await self._get_client(**kwargs).search(_input_lines(lines, filepath, size, sampling_rate, read_mode),
+                                                       on_done, on_error, on_always, data_type=DataInputType.CONTENT,
+                                                       **kwargs)
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     async def index(self, input_fn: InputFnType = None,
@@ -297,7 +302,7 @@ class AsyncFlow(BaseFlow):
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
-        await self._get_client(**kwargs).index(input_fn, on_done, on_error, on_always, **kwargs)
+        return await self._get_client(**kwargs).index(input_fn, on_done, on_error, on_always, **kwargs)
 
     @deprecated_alias(buffer='input_fn', callback='on_done', output_fn='on_done')
     async def search(self, input_fn: InputFnType = None,
@@ -342,4 +347,4 @@ class AsyncFlow(BaseFlow):
         :param on_always: the function to be called when the :class:`Request` object is  is either resolved or rejected.
         :param kwargs: accepts all keyword arguments of `jina client` CLI
         """
-        await self._get_client(**kwargs).search(input_fn, on_done, on_error, on_always, **kwargs)
+        return await self._get_client(**kwargs).search(input_fn, on_done, on_error, on_always, **kwargs)
