@@ -10,8 +10,10 @@ from ....logging import JinaLogger
 
 class HeadPea(BasePea):
 
-    def __init__(self, args: Union['argparse.Namespace', Dict]):
-        super().__init__(args)
+    def __init__(self,
+                 args: Union['argparse.Namespace', Dict],
+                 **kwargs):
+        super().__init__(args, **kwargs)
         self.name = self.__class__.__name__
         if isinstance(self.args, argparse.Namespace):
             if self.args.name:
